﻿using ConditionalClusterMarkerStyleSample.Extension;
using System.Collections.Generic;
using System.Web.Mvc;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.MvcEdition;

namespace ConditionalClusterMarkerStyleSample.Controllers
{
    public class HomeController : Controller
    {
        public ActionResult Index()
        {
            Map map = new Map("Map1", 800, 600);

            map.MapUnit = GeographyUnit.Meter;
            map.CurrentExtent = new RectangleShape(-13939426.6371, 6701997.4056, -7812401.86, 2626987.386962);

            //Style for 'ok' Cluster
            var okClusterStyle = new PointMarkerStyle()
            {
                WebImage = new WebImage(@"/Content/theme/default/img/marker_blue.gif"),
            };
            //Style for 'alert' Cluster
            var alertClusterStyle = new PointMarkerStyle()
            {
                WebImage = new WebImage(@"/Content/theme/default/img/marker.gif"),
            };

            //Add styles to a valueMarkerStyle, assign to the styles to the respective values.
            SortedValueMarkerStyle valueMarkerStyleForCluster = new SortedValueMarkerStyle("AlertStatus");
            valueMarkerStyleForCluster.ValueItems.Add(new MarkerValueItem("Ok", okClusterStyle));
            valueMarkerStyleForCluster.ValueItems.Add(new MarkerValueItem("Alert", alertClusterStyle));

            // sample Cluster by the actual data.
            var clusterMarker1 = new PointShape(-9754587.80028, 5156136.17929);
            var clusterMarker2 = new PointShape(-8922952.93266, 2984101.58384);
            var clusterMarker3 = new PointShape(-12454955.13517, 4980025.26614);
            var clusterMarker4 = new PointShape(-10772117.52067, 3864656.14956);
            var clusterMarker5 = new PointShape(-13164290.75755, 4035875.09290);
            var clusterColumnValuesOk = new Dictionary<string, string> { { "AlertStatus", "Ok" }, { "Order", "1" } };
            var clusterColumnValuesAlert = new Dictionary<string, string> { { "AlertStatus", "Alert" }, { "Order", "2" } };

            //add the featueres to the marker overlay
            InMemoryMarkerOverlay clusterMarkerOverlay = new InMemoryMarkerOverlay();

            clusterMarkerOverlay.FeatureSource.BeginTransaction();
            clusterMarkerOverlay.FeatureSource.AddFeature(clusterMarker1, clusterColumnValuesAlert);
            clusterMarkerOverlay.FeatureSource.AddFeature(clusterMarker2, clusterColumnValuesAlert);
            clusterMarkerOverlay.FeatureSource.AddFeature(clusterMarker3, clusterColumnValuesAlert);
            clusterMarkerOverlay.FeatureSource.AddFeature(clusterMarker4, clusterColumnValuesOk);
            clusterMarkerOverlay.FeatureSource.AddFeature(clusterMarker5, clusterColumnValuesOk);
            clusterMarkerOverlay.FeatureSource.CommitTransaction();

            //Set CustomMarkerStyle for markerOverlay. ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
            ClusterMarkerStyle markerStyle = new ClusterMarkerStyle(50, 800, 600);
            markerStyle.MarkerStyle = valueMarkerStyleForCluster;

            clusterMarkerOverlay.ZoomLevelSet.ZoomLevel01.CustomMarkerStyle = markerStyle;
            clusterMarkerOverlay.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level10;

            map.CustomOverlays.Add(new WorldMapKitWmsWebOverlay() { Projection = WorldMapKitProjection.SphericalMercator});
            map.CustomOverlays.Add(clusterMarkerOverlay);
          
            return View(map);
        }
    }
}
